<?php
/*
Plugin Name: User Info Shortcodes
Description: A plugin to display the user nickname, website name, and current date using shortcodes.
Version: 1.4
Author: SB
*/

// Add Shortcodes
function display_user_nickname() {
    if (is_user_logged_in()) {
        $current_user = wp_get_current_user();
        $nickname = $current_user->nickname;
        $email = $current_user->user_email;
    } else {
        $nickname = 'Guest';
        $email = 'guest@example.com'; // Use a dummy email for guest Gravatar
    }
    $avatar = get_avatar($email, 32, '', '', ['class' => 'user-nickname-avatar']); // Add CSS class to Gravatar
    return '<span style="display: inline-flex; align-items: center;">' . $avatar . ' ' . esc_html($nickname) . '</span>';
}
add_shortcode('user_nickname', 'display_user_nickname');

function display_website_name() {
    return get_bloginfo('name');
}
add_shortcode('website_name', 'display_website_name');

function display_current_date($atts) {
    $atts = shortcode_atts(
        array(
            'format' => get_option('date_format') // Default to WordPress date format
        ),
        $atts
    );
    return date_i18n($atts['format']);
}
add_shortcode('current_date', 'display_current_date');

// Create Admin Menu
function user_info_shortcodes_menu() {
    add_options_page(
        'User Info Shortcodes',
        'User Info Shortcodes',
        'manage_options',
        'user-info-shortcodes',
        'user_info_shortcodes_options_page'
    );
}
add_action('admin_menu', 'user_info_shortcodes_menu');

// Admin Page Content
function user_info_shortcodes_options_page() {
    ?>
    <div class="wrap">
        <h1>User Info Shortcodes</h1>
        <p>Use the following shortcodes to display information:</p>
        <ul>
            <li><strong>User Nickname:</strong> <code>[user_nickname]</code></li>
            <li><strong>Website Name:</strong> <code>[website_name]</code></li>
            <li><strong>Current Date:</strong> <code>[current_date]</code> (optional <code>format</code> attribute available)</li>
        </ul>
        <h2>Examples:</h2>
        <p><code>[current_date]</code> - Displays the current date in the default WordPress date format.</p>
        <p><code>[current_date format="F j, Y"]</code> - Displays the current date in the format "Month day, year" (e.g., January 1, 2024).</p>
    </div>
    <?php
}

// Add Inline CSS
function user_info_shortcodes_inline_css() {
    echo '
    <style>
    .user-nickname-avatar {
        border-radius: 50%;
        margin-right: 8px;
        width: 32px; /* Control the size of the Gravatar */
        height: 32px; /* Control the size of the Gravatar */
    }
    </style>
    ';
}
add_action('wp_head', 'user_info_shortcodes_inline_css');
?>
